package com.supervision.ngbatis.dao;

import com.supervision.ngbatis.domain.tag.Condition;
import com.supervision.ngbatis.domain.tag.ItemBranch;
import com.supervision.ngbatis.domain.tag.ItemLeaf;
import com.supervision.ngbatis.domain.tag.ProcessCondition;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * 通用查询语句
 */
public interface CommonQueryDao {

    /**
     * 根据condition_edge边,查找下级路径
     *
     * @param vid 开始节点
     * @return 下级节点列表
     */
    List<String> findNextVertxByConditionEdge(@Param("vid") String vid);

    /**
     * 根据condition_edge边,查找下级路径
     *
     * @param vid 开始节点
     * @return 下级节点列表
     */
    List<Condition> findNextConditionByConditionEdge(@Param("vid") String vid);

    /**
     * 找到叶子节点的办理条件
     *
     * @param leafVid 叶子结点的ID
     */
    ProcessCondition findConditionVertexByLeafVertex(@Param("leafVid") String leafVid);

    /**
     * 根据属性名称,去找叶子节点
     *
     * @param itemName 属性名称,从用户问题中抽取到的事项实体
     * @return 叶子节点列表
     */
    List<ItemLeaf> findItemLeafNodeVertexByItemName(@Param("itemName") String itemName);

    /**
     * 直接找所有的叶子节点
     *
     * @return 叶子节点列表
     */
    List<ItemLeaf> findAllItemLeafNodeVertex();

    /**
     * 根据属性名称,去找分支节点
     *
     * @param itemName 属性名称,从用户问题中抽取到的事项实体
     * @return 分支节点列表
     */
    List<ItemBranch> findItemBranchNodeVertexByItemName(@Param("itemName") String itemName);

    /**
     * 直接找所有分支节点
     *
     * @return 分支节点列表
     */
    List<ItemBranch> findAllItemBranchNodeVertex();

    /**
     * 根据分支节点,去寻找下面的叶子节点
     *
     * @param branchVId 分支节点ID
     * @return 叶子节点列表
     */
    List<ItemLeaf> findItemLeafByBranchId(@Param("branchVId") String branchVId);
}
